@@ -25,15 +25,27 @@ from samplics.sampling import (
     SampleSizePropTwoSample,
     allocate,
     calculate_power,
+    calculate_power_prop,
+    calculate_ss_fleiss_prop,
+    calculate_ss_wald_mean,
+    calculate_ss_wald_prop,
     power_for_one_mean,
     power_for_one_proportion,
-    power_for_proportion,
-    sample_size_for_mean_wald,
-    sample_size_for_proportion_fleiss,
-    sample_size_for_proportion_wald,
 )
-from samplics.utils.basic_functions import transform
-from samplics.utils.formats import array_to_dict
+from samplics.utils import (
+    CertaintyError,
+    MethodError,
+    PopParam,
+    ProbError,
+    SamplicsError,
+    DimensionError,
+    SelectMethod,
+    SinglePSUError,
+    SinglePSUEst,
+    SizeMethod,
+    array_to_dict,
+    transform,
+)
 from samplics.weighting import ReplicateWeight, SampleWeight
 
 
@@ -41,6 +53,10 @@ __all__ = [
     "allocate",
     "array_to_dict",
     "calculate_power",
+    "calculate_power_prop",
+    "calculate_ss_fleiss_prop",
+    "calculate_ss_wald_prop",
+    "calculate_ss_wald_mean",
     "CrossTabulation",
     "Tabulation",
     "Ttest",
@@ -60,8 +76,8 @@ __all__ = [
     "load_psu_frame",
     "load_psu_sample",
     "load_ssu_sample",
+    "PopParam",
     "power_for_one_mean",
-    "power_for_proportion",
     "power_for_one_proportion",
     "SampleSelection",
     "SampleSize",
@@ -69,15 +85,22 @@ __all__ = [
     "SampleSizeMeanTwoSample",
     "SampleSizePropOneSample",
     "SampleSizePropTwoSample",
-    "sample_size_for_mean_wald",
-    "sample_size_for_proportion_fleiss",
-    "sample_size_for_proportion_wald",
     "SampleWeight",
+    "SelectMethod",
+    "SinglePSUEst",
+    "SizeMethod",
     "SurveyGLM",
     "ReplicateWeight",
     "ReplicateEstimator",
     "TaylorEstimator",
     "transform",
+    # Custom exception classes
+    "SamplicsError",
+    "CertaintyError",
+    "DimensionError",
+    "MethodError",
+    "ProbError",
+    "SinglePSUError",
 ]
 
-__version__ = "0.3.32"
+__version__ = "0.4.3"
