@@ -12,10 +12,7 @@ from typing import Optional, Union
 import numpy as np
 import pandas as pd
 
-from scipy.stats import norm as normal
-from scipy.stats import t as student
-
-from samplics.sampling.power_functions import calculate_power, calculate_power_prop
+from samplics.sampling.power_functions import calculate_power
 from samplics.sampling.size_functions import (
     calculate_ss_fleiss_prop,
     calculate_ss_wald_mean,
@@ -25,7 +22,7 @@ from samplics.sampling.size_functions import (
     calculate_ss_wald_prop_two_samples,
 )
 from samplics.utils.formats import convert_numbers_to_dicts, dict_to_dataframe, numpy_array
-from samplics.utils.types import Array, DictStrNum, Number, PopParam, SizeMethod, StringNumber
+from samplics.utils.types import Array, DictStrNum, Number, PopParam, SizeMethod
 
 
 def allocate(
@@ -126,6 +123,21 @@ def calculate_clusters() -> None:
 class SampleSize:
     """*SampleSize* implements sample size calculation methods"""
 
+    # __slot__ = (
+    #     "param",
+    #     "method",
+    #     "strat",
+    #     "target",
+    #     "sigma",
+    #     "half_ci",
+    #     "samp_size",
+    #     "deff_c",
+    #     "deff_w",
+    #     "resp_rate",
+    #     "pop_size",
+    #     "alpha",
+    # )
+
     param: InitVar[PopParam] = field(init=True, default=PopParam.prop)
     method: InitVar[SizeMethod] = field(init=True, default=SizeMethod.wald)
     strat: InitVar[bool] = field(init=True, default=False)
@@ -314,7 +326,30 @@ class SampleSize:
 
 @dataclass
 class SampleSizeMeanOneSample:
-    """SampleSizeMeanOneSample implements sample size calculation for mean under one-sample design"""
+    """SampleSizeMeanOneSample implements sample size calculation for mean under
+    one-sample design"""
+
+    # __slots__ = (
+    #     "method",
+    #     "strat",
+    #     "two_sides",
+    #     "params_estimated",
+    #     "param",
+    #     "mean_0",
+    #     "mean_1",
+    #     "epsilon",
+    #     "delta",
+    #     "sigma",
+    #     "samp_size",
+    #     "actual_power",
+    #     "deff_c",
+    #     "deff_w",
+    #     "resp_rate",
+    #     "pop_size",
+    #     "alpha",
+    #     "beta",
+    #     "power",
+    # )
 
     method: InitVar[SizeMethod] = field(init=True, default=SizeMethod.wald)
     strat: InitVar[bool] = field(init=True, default=False)
@@ -453,7 +488,30 @@ class SampleSizeMeanOneSample:
 
 @dataclass
 class SampleSizePropOneSample:
-    """SampleSizePropOneSample implements sample size calculation for propoertion under one-sample design"""
+    """SampleSizePropOneSample implements sample size calculation for propoertion under
+    one-sample design"""
+
+    # __slots__ = (
+    #     "method",
+    #     "strat",
+    #     "two_sides",
+    #     "params_estimated",
+    #     "param",
+    #     "prop_0",
+    #     "prop_1",
+    #     "epsilon",
+    #     "delta",
+    #     "sigma",
+    #     "samp_size",
+    #     "actual_power",
+    #     "deff_c",
+    #     "deff_w",
+    #     "resp_rate",
+    #     "pop_size",
+    #     "alpha",
+    #     "beta",
+    #     "power",
+    # )
 
     method: InitVar[SizeMethod] = field(init=True, default=SizeMethod.wald)
     strat: InitVar[bool] = field(init=True, default=False)
@@ -596,7 +654,32 @@ class SampleSizePropOneSample:
 
 @dataclass
 class SampleSizeMeanTwoSample:
-    """SampleSizeMeanTwoSample implements sample size calculation for mean under two-sample design"""
+    """SampleSizeMeanTwoSample implements sample size calculation for mean under
+    two-sample design"""
+
+    # __slots__ = (
+    #     "method",
+    #     "strat",
+    #     "two_sides",
+    #     "params_estimated",
+    #     "param",
+    #     "mean_1",
+    #     "mean_2",
+    #     "epsilon",
+    #     "delta",
+    #     "sigma_1",
+    #     "sigma_2",
+    #     "equal_var",
+    #     "samp_size",
+    #     "actual_power",
+    #     "deff_c",
+    #     "deff_w",
+    #     "resp_rate",
+    #     "pop_size",
+    #     "alpha",
+    #     "beta",
+    #     "power",
+    # )
 
     method: InitVar[SizeMethod] = field(init=True, default=SizeMethod.wald)
     strat: InitVar[bool] = field(init=True, default=False)
@@ -755,7 +838,29 @@ class SampleSizeMeanTwoSample:
 
 @dataclass
 class SampleSizePropTwoSample:
-    """SampleSizeMeanTwoSample implements sample size calculation for mean under two-sample design"""
+    """SampleSizeMeanTwoSample implements sample size calculation for mean under
+    two-sample design"""
+
+    # __slots__ = (
+    #     "method",
+    #     "strat",
+    #     "two_sides",
+    #     "params_estimated",
+    #     "param",
+    #     "prop_1",
+    #     "prop_2",
+    #     "epsilon",
+    #     "delta",
+    #     "samp_size",
+    #     "actual_power",
+    #     "deff_c",
+    #     "deff_w",
+    #     "resp_rate",
+    #     "pop_size",
+    #     "alpha",
+    #     "beta",
+    #     "power",
+    # )
 
     method: InitVar[SizeMethod] = field(init=True, default=SizeMethod.wald)
     strat: InitVar[bool] = field(init=True, default=False)
