@@ -19,14 +19,6 @@ from samplics.utils.types import Array, DictStrInt, DictStrNum, Number, Series,
 
 
 def numpy_array(arr: Array) -> np.ndarray:
-    """Converts an array-like input data to np.ndarray.
-
-    Args:
-        arr (Array): array-like input data.
-
-    Returns:
-        np.ndarray: an numpy array
-    """
 
     if not isinstance(arr, np.ndarray):
         arr_np = np.asarray(arr)
@@ -38,19 +30,6 @@ def numpy_array(arr: Array) -> np.ndarray:
 
 
 def array_to_dict(arr: np.ndarray, domain: Optional[np.ndarray] = None) -> DictStrNum:
-    """Converts an array to a dictionary where the keys are the unique values of the array and
-    the values of the dictionary are the counts of the array values.
-
-    Args:
-        arr (np.ndarray): an input area.
-        domain (np.ndarray, optional): an array to provide the group associated with the
-            observations in arr. If not None, a dictionarry of dictionaries is produced.
-            Defaults to None.
-
-    Returns:
-        dict[StringNumber, Number]: a dictionary with the unique values of *arr* as keys.
-            The values of the dictionary correspond to the counts of the keys in *arr*.
-    """
 
     if domain is None:
         keys, counts = np.unique(numpy_array(arr), return_counts=True)
@@ -66,44 +45,33 @@ def array_to_dict(arr: np.ndarray, domain: Optional[np.ndarray] = None) -> DictS
 
 
 def dataframe_to_array(df: pd.DataFrame) -> np.ndarray:
-    """Returns a pandas dataframe from an np.ndarray.
-
-    Args:
-        df (pd.DataFrame): a pandas dataframe or series.
-
-    Raises:
-        AssertionError: return an exception if data is not a pandas dataframe or series.
-
-    Returns:
-        np.ndarray: an numpy array.
-    """
 
     if isinstance(df, pd.Series):
         x_array = df
     elif isinstance(df, pd.DataFrame):
         nb_vars = df.shape[1]
-        varlist = df.columns
-        x_array = df[varlist[0]]
+        col_names = df.columns
+        x_array = df[col_names[0]]
         if nb_vars > 1:
             for k in range(1, nb_vars):
-                x_array = x_array.astype(str) + "_&_" + df[varlist[k]].astype(str)
+                x_array = x_array.astype(str) + "_&_" + df[col_names[k]].astype(str)
     else:
         raise AssertionError("The input data is not a pandas dataframe")
 
     return np.asarray(x_array.to_numpy())
 
 
-def sample_size_dict(
-    sample_size: Union[DictStrInt, int],
-    stratification: bool,
+def data_to_dict(
+    data: Union[DictStrInt, int],
+    strat: bool,
     stratum: Array,
 ) -> Union[DictStrInt, int]:
-    if not isinstance(sample_size, dict) and stratification:
-        return dict(zip(stratum, np.repeat(sample_size, len(stratum))))
-    if isinstance(sample_size, (int, float)) and not stratification:
-        return sample_size
-    elif isinstance(sample_size, dict):
-        return sample_size
+    if not isinstance(data, dict) and strat:
+        return dict(zip(stratum, np.repeat(data, len(stratum))))
+    if isinstance(data, (int, float)) and not strat:
+        return data
+    elif isinstance(data, dict):
+        return data
     else:
         raise AssertionError
 
@@ -149,35 +117,48 @@ def dict_to_dataframe(col_names: list[str], *args: Any) -> pd.DataFrame:
                 values_df[col_names[k + 2]] = arg.values()
     else:
         values_df = pd.DataFrame({args})
-        values_df.insert(0, "_parameter", None)
+        values_df.insert(0, "_parameter", " ")
         values_df.columns = col_names
 
     return values_df
 
 
-def remove_nans(excluded_units: Array, *args: Any) -> list:
+# def remove_nans(excluded_units: Array, *args: Any) -> list:
+
+#     excluded_units = numpy_array(excluded_units)
+#     vars_list = list()
+#     for var in args:
+#         if var is not None and len(var.shape) != 0:
+#             vars_list.append(var[~excluded_units])
+#         else:
+#             vars_list.append(None)
+
+#     return vars_list
+
+
+def remove_nans(n: Number, *args: np.ndarray) -> list:
+
+    excluded_units = np.zeros(n).astype(bool)
 
-    excluded_units = numpy_array(excluded_units)
-    vars = list()
     for var in args:
-        if var is not None and len(var.shape) != 0:
-            vars.append(var[~excluded_units])
-        else:
-            vars.append(None)
+        if var.shape not in ((), (0,)):
+            assert n == var.shape[0]
+            if var.dtype.kind in ("i", "u", "f", "c", "b", "m", "M"):
+                excluded_units = excluded_units | np.isnan(var)
+            else:
+                var = var.astype(str)
+                excluded_units = excluded_units | np.isin(var, ("nan", ""))
 
-    return vars
+    return ~excluded_units
 
 
-def fpc_as_dict(stratum: Optional[Array], fpc: Union[Array, Number]) -> Union[DictStrNum, Number]:
+def fpc_as_dict(stratum: np.ndarray, fpc: Union[Array, Number]) -> Union[DictStrNum, Number]:
 
-    if stratum is not None:
-        stratum = numpy_array(stratum)
-
-    if stratum is None and isinstance(fpc, (int, float)):
+    if stratum.shape in ((), (0,)) and isinstance(fpc, (int, float)):
         return fpc
-    elif stratum is not None and isinstance(fpc, (int, float)):
+    elif stratum.shape not in ((), (0,)) and isinstance(fpc, (int, float)):
         return dict(zip(stratum, np.repeat(fpc, stratum.shape[0])))
-    elif stratum is not None and isinstance(fpc, np.ndarray):
+    elif stratum.shape not in ((), (0,)) and isinstance(fpc, np.ndarray):
         return dict(zip(stratum, fpc))
     else:
         raise TypeError("stratum and fpc are not compatible!")
@@ -220,20 +201,13 @@ def convert_numbers_to_dicts(
 
 
 def concatenate_series_to_str(row: Series) -> str:
-    """concatenate the elements into one string using '_' to separate the elements
 
-    Args:
-        row (Array): [description]
-
-    Returns:
-        str: [description]
-    """
     return "__by__".join([str(c) for c in row])
 
 
-def numpy_to_dummies(arr: np.ndarray, varsnames: list[str]) -> np.ndarray:
+def numpy_to_dummies(arr: np.ndarray, vars_names: list[str]) -> np.ndarray:
 
     df = pd.DataFrame(arr.astype(str))
-    df.columns = varsnames
+    df.columns = vars_names
 
     return np.asarray(pd.get_dummies(df, drop_first=True).to_numpy())
